@@ -3,7 +3,7 @@ package GUIDeFATE;
    use strict;
    use warnings;
    
-   our $VERSION = '0.062';
+   our $VERSION = '0.065';
    
    use Exporter 'import';
    
@@ -38,7 +38,7 @@ sub new{
 		eval " use GFwin32 qw<addButton addStatText addTextCtrl addMenuBits addPanel setScale 
 		           \$frame \$winScale \$winWidth \$winHeight \$winTitle>;";
 		convert($textGUI, $target);
-		return GFtk->new(); 
+		return GFwin32->new(); 
 	}
 	
 }
@@ -53,6 +53,7 @@ sub convert{
 	my $debug= $assist=~/d/;
 	my $auto= $assist=~/a/;
 	
+	if (!exists &{"setScale"}){print "Error exists in GF$target\n"; return;}
 	setScale($winScale);  # makes scaling in the two modules match
 	
 	if ($lines[0] =~ /\-(\d+)x(\d+)-/){
@@ -86,6 +87,7 @@ sub convert{
 			}
 			$fh++;
 			if ($ps  && ($fh-2)) {
+				$content=~s/^\s+|\s+$//g;
 				$log="SubPanel '$panelType' Id $bid found position  $ps height $fh width $fl at row $l with content $content \n";##
 				if ($verbose){ print $log; }
 				if ($auto){ $autoGen.="#".$log; }
@@ -108,7 +110,9 @@ sub convert{
 			$log= "Text Control with default text ' $content ', calls function &textctrl$bid \n"; ##
 			if ($verbose){ print $log; }
 			if ($auto){ $autoGen.=makeSub("textctrl$bid","Text Control with default text ' $content '" ); }	
-			addTextCtrl([$bid, $content,[$winScale*($ps*2-1),$winScale*$l*4],[$winScale*(length($content)*2+3),$winScale*4], \&{"main::textctrl".$bid++}]);
+			my $trimmed=$content; $trimmed=~s/(\s+)|(\s+)$//g; 
+			addTextCtrl([$bid, $trimmed,[$winScale*($ps*2-1),$winScale*$l*4],[$winScale*(length($content)*2+3),$winScale*4], \&{"main::textctrl".$bid}]);
+			$bid++;
 			$line=~s/(\[([^\]]+)\])/" " x length($1)/e;     #remove text controls replacing with spaces
 		}
 		if ($line !~ m/\+/){
@@ -182,8 +186,8 @@ sub convert{
 		}
 	
 	sub makeSub{
-	  my ($subName, $trigger)=@_;
-	  return "sub $subName #called using $trigger\n  {\n  # subroutione code goes here\n   };\n\n";
+	  my ($subName,$trigger)=@_;
+	  return "sub $subName #called using $trigger {\n  # subroutione code goes here\n   };\n\n";
     }
 
 
@@ -270,6 +274,6 @@ Saif Ahmed, SAIFTYNET { at } gmail.com
 
 =head1 SEE ALSO
 
-L<Wx>, L<Tk>, L<Image::Magick>, L<Wx::Perl::Magick>,
+L<Wx>, L<Tk>, L<Image::Magick>, L<Wx::Perl::Imagick>,
 
 =cut
